.. _Mockups:

*******
Mockups
*******

Main Page
=========

.. image:: _static/images/mockups/mockup1.png


Chat page
=========

.. image:: _static/images/mockups/mockup2.png


Other pages
===========

Others pages like "Privacy", "License",... etc. are simply text page with header and footer. Such pages aren't saved in
Database they are plain html files. Because such pages are not dynamic they are cashed.
